==> haskell-gi-cairo-connector-0.1.1-195-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-cairo-connector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-cairo-connector
version:              0.1.1
visibility:           public
id:                   gi-cairo-connector-0.1.1-B8aI0z0n1viKE3p5VtSM2n
key:                  gi-cairo-connector-0.1.1-B8aI0z0n1viKE3p5VtSM2n
license:              LGPL-2.1-only
copyright:            (c) 2018 Kilian Kilger, Iñaki García Etxebarria
maintainer:           Kilian Kilger (kkilger@gmail.com)
author:
    Iñaki García Etxebarria,
    Kilian Kilger

stability:            experimental
homepage:             https://github.com/cohomology/gi-cairo-render
synopsis:             GI friendly Binding to the Cairo library.
description:
    This library contains glue code used to interconnect Haskell GI and Cairo

category:             Graphics
abi:                  b01aa6f33a1442e681afee61f95d27b1
exposed:              True
exposed-modules:      GI.Cairo.Render.Connector
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-cairo-connector
hs-libraries:         HSgi-cairo-connector-0.1.1-B8aI0z0n1viKE3p5VtSM2n
depends:
    base-4.17.2.1 gi-cairo-1.0.29-DYIvFJ5Wlo9GCkFdv7KMty
    gi-cairo-render-0.1.2-Haw5VxJsY991vIM8TAK3V9
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg mtl-2.2.2

haddock-interfaces:
    /usr/share/doc/haskell-gi-cairo-connector/html/gi-cairo-connector.haddock

haddock-html:         /usr/share/doc/haskell-gi-cairo-connector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-cairo-connector-0.1.1-196-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-cairo-connector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-cairo-connector
version:              0.1.1
visibility:           public
id:                   gi-cairo-connector-0.1.1-5aJDpDWjuCWA77CskIsMdb
key:                  gi-cairo-connector-0.1.1-5aJDpDWjuCWA77CskIsMdb
license:              LGPL-2.1-only
copyright:            (c) 2018 Kilian Kilger, Iñaki García Etxebarria
maintainer:           Kilian Kilger (kkilger@gmail.com)
author:
    Iñaki García Etxebarria,
    Kilian Kilger

stability:            experimental
homepage:             https://github.com/cohomology/gi-cairo-render
synopsis:             GI friendly Binding to the Cairo library.
description:
    This library contains glue code used to interconnect Haskell GI and Cairo

category:             Graphics
abi:                  2d306d1f94163ad9dd3273a86f783f86
exposed:              True
exposed-modules:      GI.Cairo.Render.Connector
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-cairo-connector
hs-libraries:         HSgi-cairo-connector-0.1.1-5aJDpDWjuCWA77CskIsMdb
depends:
    base-4.17.2.1 gi-cairo-1.0.29-9eYx8RoOXKt939SC0AzsjH
    gi-cairo-render-0.1.2-Haw5VxJsY991vIM8TAK3V9
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg mtl-2.2.2

haddock-interfaces:
    /usr/share/doc/haskell-gi-cairo-connector/html/gi-cairo-connector.haddock

haddock-html:         /usr/share/doc/haskell-gi-cairo-connector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
